"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.editorTypes = void 0;

var _sqlFormatter = _interopRequireDefault(require("sql-formatter"));

var _pretty = _interopRequireDefault(require("pretty"));

var _jsBeautify = _interopRequireDefault(require("js-beautify"));

var parse = function parse(value) {
  return value;
};

var stringify = function stringify(value) {
  var _value;

  return ((_value = value) !== null && _value !== void 0 ? _value : '').toString();
};

var editorTypes = {
  sql: {
    mode: 'text/x-sql',
    format: function format(value) {
      return _sqlFormatter.default.format(value);
    },
    parse: parse,
    stringify: stringify
  },
  json: {
    mode: 'application/json',
    format: function format(value) {
      try {
        if (typeof value === 'string') {
          return JSON.stringify(JSON.parse(value), null, 2);
        }

        return JSON.stringify(value, null, 2);
      } catch (_unused) {
        return value;
      }
    },
    parse: function parse(value) {
      try {
        if (typeof value === 'string') return JSON.parse(value);
      } catch (_unused2) {
        return value;
      }
    },
    stringify: function stringify(value) {
      if (value) {
        if (typeof value === 'string') return value;

        try {
          return JSON.stringify(value, null, 2);
        } catch (_unused3) {
          return value;
        }
      }

      return '';
    }
  },
  html: {
    mode: 'text/html',
    format: function format(value) {
      return (0, _pretty.default)(value);
    },
    parse: parse,
    stringify: stringify
  },
  javascript: {
    mode: 'javascript',
    format: function format(value) {
      return (0, _jsBeautify.default)(value, {
        indent_size: 2,
        space_in_empty_paren: true
      });
    },
    parse: parse,
    stringify: stringify
  }
};
exports.editorTypes = editorTypes;